@@ -24,8 +24,16 @@ def test_script(capfd: pytest.CaptureFixture[str]) -> None:
     assert not err
 
 
-def test_main_py(mocker: MockerFixture, monkeypatch: pytest.MonkeyPatch) -> None:
+def test_main_py(mocker: MockerFixture, monkeypatch: pytest.MonkeyPatch, tmp_path: Path) -> None:
+    monkeypatch.chdir(tmp_path)
     monkeypatch.delenv("PIP_INDEX_URL", raising=False)
+    monkeypatch.delenv("NPM_REGISTRY_CONFIG", raising=False)
     run = mocker.patch("bump_deps_index.run")
     main(["A"])
-    run.assert_called_once_with(Options(index_url="https://pypi.org/simple", pkgs=["A"], filename=None))
+    opt = Options(
+        index_url="https://pypi.org/simple",
+        npm_registry="https://registry.npmjs.org",
+        pkgs=["A"],
+        filenames=[],
+    )
+    run.assert_called_once_with(opt)
